==> ember-cli-deploy-elasticbeanstalk-0.0.1.tgz: package/index.js <==

/* jshint node: true */
'use strict';
var path             = require('path');
var Promise          = require('ember-cli/lib/ext/promise');
var DeployPluginBase = require('ember-cli-deploy-plugin');
var fs = require('fs-extra');

module.exports = {
  name: 'ember-cli-deploy-elasticbeanstalk',

  createDeployPlugin: function(options) {
    var DeployPlugin = DeployPluginBase.extend({
      name: options.name,

      defaultConfig: {
        filePattern: 'index.html',
        assetDir: '',
        distDir: function(context) {
          return context.distDir;
        },
        revisionKey: function(context) {
          var revisionKey = context.revisionData && context.revisionData.revisionKey;
          return context.commandOptions.revision || revisionKey;
        }
      },
      requiredConfig: ['deployPath'],

      upload: function() {
        var deployPath     = this.readConfig('deployPath');
        var revisionKey    = this.readConfig('revisionKey');
        var filePattern    = this.readConfig('filePattern');
        var distDir        = this.readConfig('distDir');
        var deployAssetDir = this.readConfig('assetDir');
        var filePath       = path.join(distDir, filePattern);
        var destFilePath   = path.join(deployPath, deployAssetDir, filePattern);
        
        var copy = Promise.denodeify(require('fs-extra').copy);
        this.log('Uploading ' + filePattern);

        return copy(filePath, destFilePath)
          .then(() => {
            var exec = Promise.denodeify(require('child_process').exec);
            this.log('index file copied');
            this.log(deployPath);
            return exec('eb deploy', { cwd: deployPath });
          })
          .then((stdout) => {
            this.log(stdout);
          }).catch(err => {
            this.log(err, { color: 'red' });
          });
      },

      activate: function(context) {
        // todo: make this work
      },

      fetchRevisions: function(context) {
        // todo: make this work
      }
    });

    return new DeployPlugin();
  }
};

==> ember-cli-deploy-elasticbeanstalk-0.0.3.tgz: package/index.js <==

/* jshint node: true */
'use strict';
var path             = require('path');
var RSVP      = require('rsvp');
var DeployPluginBase = require('ember-cli-deploy-plugin');
var fs = require('fs-extra');

module.exports = {
  name: 'ember-cli-deploy-elasticbeanstalk',

  createDeployPlugin: function(options) {
    var DeployPlugin = DeployPluginBase.extend({
      name: options.name,

      defaultConfig: {
        filePattern: 'index.html',
        assetDir: '',
        distDir: function(context) {
          return context.distDir;
        },
        revisionKey: function(context) {
          var revisionKey = context.revisionData && context.revisionData.revisionKey;
          return context.commandOptions.revision || revisionKey;
        }
      },
      requiredConfig: ['deployPath'],

      upload: function() {
        var deployPath     = this.readConfig('deployPath');
        var revisionKey    = this.readConfig('revisionKey');
        var filePattern    = this.readConfig('filePattern');
        var distDir        = this.readConfig('distDir');
        var deployAssetDir = this.readConfig('assetDir');
        var filePath       = path.join(distDir, filePattern);
        var destFilePath   = path.join(deployPath, deployAssetDir, filePattern);
        
        var copy = RSVP.denodeify(require('fs-extra').copy);
        this.log('Uploading ' + filePattern);

        return copy(filePath, destFilePath)
          .then(() => {
            var exec = RSVP.denodeify(require('child_process').exec);
            this.log('index file copied');
            this.log(deployPath);
            return exec('eb deploy', { cwd: deployPath });
          })
          .then((stdout) => {
            this.log(stdout);
          }).catch(err => {
            this.log(err, { color: 'red' });
          });
      },

      activate: function(context) {
        // todo: make this work
      },

      fetchRevisions: function(context) {
        // todo: make this work
      }
    });

    return new DeployPlugin();
  }
};
